the results generated from running
checknetMHCpan()
export_dir
the export directory where the results .csv files should
be exported.
Value
exports a folder containing three files
netMHCpan results in long format (the original output)(.csv file)
netMHCpan results tidied (in wide format) so as to summarize
the information per peptide (.tsv tab-separated file)
the updated database search results which contain the categorizatiosn
of the peptides found in common between the 2nd database search and
the HybridFinder function (.csv file)
Details
In order to be able to have the checknetMHCpan() function results
exported, this function will come in handy. Please note that this function is
also part of the checknetMHCpan() function (if export_files is set to TRUE
and a valid export directory is indicated)