the results generated from running
step2_wo_netMHCpan()
export_dir
the export directory where you would like to have the .csv
file saved.
Value
exports a folder containing 2 files
the peptide list to be entered in a netMHCpan-ready format,(.csv)
the updated database search results which contain the categorizatiosn
of the peptides found in common between the 2nd database search and
the HybridFinder function (.csv file)
Details
Since netMHCpan is not compatible with Windows OS, the package offers
an alternative by outputting the input for netMHCpan and as well the database
results with their respective categorizations (cis, trans) established in step1.