Learn R Programming

RHybridFinder (version 0.2.0)

mhc_check: mhc_check

Description

this function only contains the alleles list, read by netMHCpan, the list was retrieved by reading the file exported from netMHCpan, using the following command line "netMHCpan -listMHC"

Usage

mhc_check(netmhcpan_alleles)

Arguments

netmhcpan_alleles

the netmhcpan alleles to be used for the netmhcpan call.

Value

  • returns a custom error message if MHC/HLA allele(s) are not written correctly

  • returns nothing if there are no issues. If HLA alleles are not written correctly

Details

a custom error is printed in case the allele is not written correctly

Examples

Run this code
# NOT RUN {
if (interactive()) {
 mhc_check("HLA-A02:01")
 mhc_check("HLA-A0201")
}
# }

Run the code above in your browser using DataLab