Learn R Programming

RHybridFinder (version 0.2.0)

netmhcpan_list_alleles: netmhcpan_list_alleles

Description

the list of alleles in the acceptable format for netMHCpan

Usage

netmhcpan_list_alleles

Arguments

Format

A data frame with 1024 rows and 1 variables:

V1

character the alleles

Details

the list of alleles in the acceptable format for netMHCpan